(join-peer state source request environment)Local peer is joining the domain.
Updates the state and generates messages to all existing peers announcing the new peer
Local peer is joining the domain. Updates the state and generates messages to all existing peers announcing the new peer
(source-removed state source _)Source has disconnected from the system
Source has disconnected from the system
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |